@@ -14,8 +14,10 @@ class ChunkingProcessor(SeqLabProcessor):
         return TaskType.chunking
 
     @classmethod
-    def default_metrics(cls, language=None) -> list[MetricConfig]:
-        return [BIOF1ScoreConfig(name='F1', language=language)]
+    def default_metrics(
+        cls, source_language=None, target_language=None
+    ) -> list[MetricConfig]:
+        return [BIOF1ScoreConfig(name='F1')]
 
     @classmethod
     def default_span_ops(cls) -> BIOSpanOps:
