@@ -14,8 +14,16 @@ class NERProcessor(SeqLabProcessor):
         return TaskType.named_entity_recognition
 
     @classmethod
-    def default_metrics(cls, language=None) -> list[MetricConfig]:
-        return [BIOF1ScoreConfig(name='F1', language=language)]
+    def default_metrics(
+        cls, source_language=None, target_language=None
+    ) -> list[MetricConfig]:
+        return [
+            BIOF1ScoreConfig(
+                name='F1',
+                source_language=source_language,
+                target_language=target_language,
+            )
+        ]
 
     @classmethod
     def default_span_ops(cls) -> BIOSpanOps:
