@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import abc
 from collections import defaultdict
+from dataclasses import dataclass
 from typing import Any, Optional
 
 
@@ -23,120 +24,35 @@ def cap_feature(s):
         return "not_first_caps"
 
 
-def get_spans_from_bio(bio_seq: list[str]) -> list[tuple[str, int, int]]:
-    """
-    Takes in a BIO-tagged sequence of tokens, and returns tagged spans.
-    :param bio_seq: A sequence of bio-tagged strings
-                    such as ['O', 'B-PER', 'I-PER', 'B-ORG', 'O']
-    :return: A sequence of spans in format (tag,begin,end),
-             such as [('PER',1,3), ('ORG',3,4)]
-    """
-
-    default = 'O'
-    # idx_to_tag = {idx: tag for tag, idx in tags.items()}
-    spans = []
-    span_type, span_start = None, -1
-    for i, tok in enumerate(bio_seq):
-        # End of a span 1
-        if tok == default and span_type is not None:
-            # Add a span.
-            span = (span_type, span_start, i)
-            spans.append(span)
-            span_type, span_start = None, -1
-
-        # End of a span + start of a span!
-        elif tok != default:
-
-            tok_span_class, tok_span_type = tok.split('-')
-            if span_type is None:
-                span_type, span_start = tok_span_type, i
-            elif tok_span_type != span_type or tok_span_class == "B":
-                span = (span_type, span_start, i)
-                spans.append(span)
-                span_type, span_start = tok_span_type, i
-        else:
-            pass
-    # end condition
-    if span_type is not None:
-        span = (span_type, span_start, len(bio_seq))
-        spans.append(span)
-
-    return spans
-
-
-def get_spans_from_bmes(seq: list) -> list[tuple[str, int, int]]:
-    """
-    :param seq: ["B", "E", "S", "B", "E","B","M","E"]
-    :return:
-    ([('BE', 0, 2), ('S', 2, 3), ('BE', 3, 5), ('BME', 5, 8)],
-     ['BE', 'BE', 'S', 'BE', 'BE', 'BME', 'BME', 'BME'])
-    """
-    spans = []
-    w_start = 0
-    chunk = None
-    tag = ""
-
-    for i, tok in enumerate(seq):
-        tag += tok
-        if tok == "S":
-            chunk = ("S", i, i + 1)
-            spans.append(chunk)
-
-            tag = ""
-        if tok == "B":
-            w_start = i
-        if tok == "E":
-            chunk = (tag, w_start, i + 1)
-            spans.append(chunk)
-
-            tag = ""
-
-    return spans
-
-
+@dataclass
 class Span:
-    def __init__(
-        self,
-        # surface string a span
-        span_text: Optional[str] = None,
-        # the tag of a span
-        span_tag: Optional[str] = None,
-        # whether span could be matched
-        span_matched: int = 0,
-        # the position of a span
-        span_pos: Optional[tuple] = None,
-        # span capital features
-        span_capitalness: Optional[str] = None,
-        # the relative position of a span in a sequence
-        span_rel_pos: Optional[float] = None,
-        # the number of characters of a span
-        span_chars: Optional[int] = None,
-        # the number of tokens of a span
-        span_tokens: Optional[int] = None,
-        # the consistency of span label in training set
-        span_econ: Optional[float] = None,
-        # the frequency of a span in training set
-        span_efre: Optional[float] = None,
-        # the id of samples where a span is located
-        sample_id: Optional[int] = None,
-        # the frequency of span in test set
-        span_test_freq: Optional[float] = None,
-        # the frequency of span in training set (TODO: duplicated?)
-        span_train_freq: Optional[float] = None,
-    ):
-        self.span_text = span_text
-        self.span_tag = span_tag
-        self.span_pos = span_pos
-        self.span_matched = span_matched
-        self.span_capitalness = span_capitalness
-        self.span_rel_pos = span_rel_pos
-        self.span_chars = span_chars
-        self.span_tokens = span_tokens
-        self.span_econ = span_econ
-        self.span_efre = span_efre
-        self.sample_id = sample_id
-        self.span_test_freq = span_test_freq
-        self.span_train_freq = span_train_freq
+
+    # surface string a span
+    span_text: Optional[str] = None
+    # the tag of a span
+    span_tag: Optional[str] = None
+    # whether span could be matched
+    span_matched: int = 0
+    # the position of a span
+    span_pos: Optional[tuple] = None
+    # span capital features
+    span_capitalness: Optional[str] = None
+    # the relative position of a span in a sequence
+    span_rel_pos: Optional[float] = None
+    # the number of characters of a span
+    span_chars: Optional[int] = None
+    # the number of tokens of a span
+    span_tokens: Optional[int] = None
+    # the consistency of span label in training set
+    span_econ: Optional[float] = None
+    # the frequency of a span in training set
+    span_efre: Optional[float] = None
+    # the id of samples where a span is located
+    sample_id: Optional[int] = None
+    # the frequency of span in test set
+    span_test_freq: Optional[float] = None
+    # the frequency of span in training set (TODO: duplicated?)
+    span_train_freq: Optional[float] = None
 
     @property
     def get_span_tag(self):
@@ -157,6 +73,10 @@ class SpanOps:
         )
         self.match_func = self.get_match_funcs()[self.match_type]
 
+    def set_resources(self, resources: dict[str, Any]):
+        self.resources = resources
+        return resources
+
     @classmethod
     def default_match_type(cls) -> str:
         return "tag"
@@ -204,6 +124,11 @@ class SpanOps:
         """Return spans from a sequence of tags and tokens"""
         ...
 
+    @abc.abstractmethod
+    def get_spans_simple(self, tags: list, seq: Optional[list] = None) -> list:
+        """Return spans from a sequence of tags and tokens"""
+        ...
+
     def get_matched_spans(
         self, spans_a: list[Span], spans_b: list[Span]
     ) -> tuple[list[int], list[int], list[Span], list[Span]]:
@@ -314,6 +239,35 @@ class BMESSpanOps(SpanOps):
     def default_match_type(cls) -> str:
         return "position_tag"
 
+    def get_spans_simple(self, tags: list, seq: Optional[list] = None) -> list:
+        """
+        :param seq: ["B", "E", "S", "B", "E","B","M","E"]
+        :return:
+        ([('BE', 0, 2), ('S', 2, 3), ('BE', 3, 5), ('BME', 5, 8)],
+         ['BE', 'BE', 'S', 'BE', 'BE', 'BME', 'BME', 'BME'])
+        """
+        spans = []
+        w_start = 0
+        chunk = None
+        tag = ""
+
+        for i, tok in enumerate(tags):
+            tag += tok
+            if tok == "S":
+                chunk = ("S", i, i + 1)
+                spans.append(chunk)
+
+                tag = ""
+            if tok == "B":
+                w_start = i
+            if tok == "E":
+                chunk = (tag, w_start, i + 1)
+                spans.append(chunk)
+
+                tag = ""
+
+        return spans
+
     def get_spans(self, tags: list, seq: Optional[list] = None) -> list[Span]:
         """
         :param seq: ["B", "E", "S", "B", "E","B","M","E"]
@@ -338,6 +292,7 @@ class BMESSpanOps(SpanOps):
                     span_pos=(i, i + 1),
                     span_rel_pos=i * 1.0 / len(tags),
                     span_chars=len(span_text),
+                    span_tokens=len(span_text.split(" ")),
                 )
                 if "has_stats" in self.resources.keys() and self.resources["has_stats"]:
                     lower_tag = span.span_tag
@@ -359,6 +314,7 @@ class BMESSpanOps(SpanOps):
                     span_pos=(w_start, i + 1),
                     span_rel_pos=w_start * 1.0 / len(tags),
                     span_chars=len(span_text),
+                    span_tokens=len(span_text.split(" ")),
                 )
                 if "has_stats" in self.resources.keys() and self.resources["has_stats"]:
                     lower_tag = span.span_tag
@@ -475,3 +431,43 @@ class BIOSpanOps(SpanOps):
             spans.append(span)
 
         return spans
+
+    def get_spans_simple(self, tags: list, seq: Optional[list] = None) -> list:
+        """
+        Takes in a BIO-tagged sequence of tokens, and returns tagged spans.
+        :param bio_seq: A sequence of bio-tagged strings
+                        such as ['O', 'B-PER', 'I-PER', 'B-ORG', 'O']
+        :return: A sequence of spans in format (tag,begin,end),
+                 such as [('PER',1,3), ('ORG',3,4)]
+        """
+
+        default = 'O'
+        # idx_to_tag = {idx: tag for tag, idx in tags.items()}
+        spans = []
+        span_type, span_start = None, -1
+        for i, tok in enumerate(tags):
+            # End of a span 1
+            if tok == default and span_type is not None:
+                # Add a span.
+                span = (span_type, span_start, i)
+                spans.append(span)
+                span_type, span_start = None, -1
+
+            # End of a span + start of a span!
+            elif tok != default:
+
+                tok_span_class, tok_span_type = tok.split('-')
+                if span_type is None:
+                    span_type, span_start = tok_span_type, i
+                elif tok_span_type != span_type or tok_span_class == "B":
+                    span = (span_type, span_start, i)
+                    spans.append(span)
+                    span_type, span_start = tok_span_type, i
+            else:
+                pass
+        # end condition
+        if span_type is not None:
+            span = (span_type, span_start, len(tags))
+            spans.append(span)
+
+        return spans
